@@ -4,6 +4,32 @@ import json
 from fcache.cache import FileCache
 
 
+def get_conn(all_creds: dict, conn_name: str, config_file: str):
+    """Finds default connection in config file."
+
+    Args:
+        all_creds: Dictionary of all credentials
+        conn_name: Name of connection (if passed)
+        config_file: Name of config file (for console output only)
+
+    Returns:
+        Name of the set of credentials to be parsed out of the
+        credentials file
+
+    """
+    print("\nImporting credentials...")
+    if not conn_name:
+        conn_name = next(iter(all_creds.keys()))
+        print(f"\t<1 of 2> No explicit connection passed, fetching "
+              f"'{conn_name}' credentials by default")
+
+    else:
+        print(f"\t<1 of 2> Fetching user-specific 'conn_name={conn_name}' "
+              f"from {config_file}")
+
+    return conn_name
+
+
 class Credentials:
 
     def __init__(self, config_file: str = 'snowflake_credentials.json',
@@ -19,7 +45,7 @@ class Credentials:
         """
         self.cache = FileCache('snowmobile', flag='cs')
         self.config_file = config_file
-        self.conn_name = conn_name
+        self.conn_name = conn_name.lower()
         self.path_to_config = self.cache.get(r'path_to_config')
 
     def clear_cache(self) -> object:
@@ -83,32 +109,6 @@ class Credentials:
 
         return self.path_to_config
 
-    @staticmethod
-    def get_conn(all_creds: dict, conn_name: str, config_file: str):
-        """Finds default connection in config file."
-
-        Args:
-            all_creds: Dictionary of all credentials
-            conn_name: Name of connection (if passed)
-            config_file: Name of config file (for console output only)
-
-        Returns:
-            Name of the set of credentials to be parsed out of the
-            credentials file
-
-        """
-        print("\nImporting credentials...")
-        if not conn_name:
-            conn_name = next(iter(all_creds.keys()))
-            print(f"\t<1 of 2> No explicit connection passed, fetching "
-                  f"'{conn_name}' credentials by default")
-
-        else:
-            print(f"\t<1 of 2> Fetching user-specific 'conn_name={conn_name}' "
-                  f"from {config_file}")
-
-        return conn_name
-
     def get(self) -> dict:
         """Locates creds file and parses out the specified set of credentials.
 
@@ -121,16 +121,17 @@ class Credentials:
 
         try:
             with open(self.path_to_config) as c:
-                all_creds = json.load(c)
-                all_creds = {k.lower: v for k, v in all_creds.items()}
+                self.all_creds = json.load(c)
+                self.all_creds = \
+                    {k.lower: v for k, v in self.all_creds.items()}
 
         except IOError as e:
             print(e)
 
         try:
-            self.conn_name = self.get_conn(all_creds, self.conn_name,
+            self.conn_name = get_conn(self.all_creds, self.conn_name,
                                            self.config_file)
-            creds = all_creds.get(self.conn_name.lower())
+            creds = self.all_creds.get(self.conn_name)
             print(f"\t<2 of 2> Successfully imported credentials for "
                   f"'{self.conn_name}'")
             return creds
